@@ -11,7 +11,17 @@ import colorlog
 import logging
 import logging.handlers
 
-LOG_FILENAME = Path(SETTINGS.DEFAULT.BASE_DIR).expanduser() / SETTINGS.DEFAULT.LOG_FILE
+# Revert base directory to local if there's an access problem
+
+BASE_DIR = Path(SETTINGS.DEFAULT.BASE_DIR).expanduser()
+try:
+    BASE_DIR.mkdir(exist_ok=True, parents=True)
+except OSError:
+    BASE_DIR = Path(__file__).parent.parent.parent / "_build"
+    BASE_DIR.mkdir(exist_ok=True, parents=True)
+    SETTINGS.DEFAULT.BASE_DIR = str(BASE_DIR)
+
+LOG_FILENAME = BASE_DIR / SETTINGS.DEFAULT.LOG_FILE
 
 # Set up a specific logger with our desired output level
 logger = logging.getLogger()
