@@ -14,15 +14,25 @@ class Schema(XmlSchema):
 
 class InpadocModel(Model):
     biblio = one_to_one("patent_client.epo.published.model.InpadocBiblio", doc_number="docdb_number")
-    claims = one_to_one("patent_client.epo.published.model.Claims", attribute="claims", doc_number="docdb_number")
+    claims = one_to_one(
+        "patent_client.epo.published.model.Claims",
+        attribute="claims",
+        doc_number="docdb_number",
+    )
     claim_text = one_to_one(
-        "patent_client.epo.published.model.Claims", attribute="claim_text", doc_number="docdb_number"
+        "patent_client.epo.published.model.Claims",
+        attribute="claim_text",
+        doc_number="docdb_number",
     )
     description = one_to_one(
-        "patent_client.epo.published.model.Description", attribute="description", doc_number="docdb_number"
+        "patent_client.epo.published.model.Description",
+        attribute="description",
+        doc_number="docdb_number",
     )
     family = one_to_one(
-        "patent_client.epo.family.model.Family", attribute="family_members", doc_number="docdb_number"
+        "patent_client.epo.family.model.Family",
+        attribute="family_members",
+        doc_number="docdb_number",
     )
     images = one_to_one("patent_client.epo.published.model.Images", doc_number="docdb_number")
     legal = one_to_one("patent_client.epo.legal.model.Legal", doc_number="docdb_number")
