@@ -1,2 +1,7 @@
 from .patent.model import Patent
 from .published_application.model import PublishedApplication
+
+__all__ = [
+    "Patent",
+    "PublishedApplication",
+]
