@@ -1,13 +1,14 @@
-import pytest
 from dataclasses import dataclass
+
+import pandas as pd
+import pytest
+
 from .model import Model
 from .row import Row
 
-import pandas as pd
 
 def test_model():
-
-    class DummyManager():
+    class DummyManager:
         pass
 
     @dataclass
@@ -15,7 +16,7 @@ def test_model():
         __manager__ = DummyManager
         a: str = None
         b: int = None
-    
+
     ex = Example(a="1", b=2)
     assert len(ex.fields()) == 2
     assert ex.a == "1"
@@ -36,22 +37,30 @@ def test_model():
     assert s.to_json() == '{"a":"1","b":2}'
     assert type(Example.objects) == DummyManager
 
+
 def test_exclude_fields():
     @dataclass
     class Example(Model):
-        __exclude_fields__ = ['b',]
+        __exclude_fields__ = [
+            "b",
+        ]
         a: str = None
         b: int = None
+
     ex = Example(a="1", b=2)
     row = ex.to_dict()
     assert "b" not in row
 
+
 def test_default_fields():
     @dataclass
     class Example(Model):
-        __default_fields__ = ['a',]
+        __default_fields__ = [
+            "a",
+        ]
         a: str = None
         b: int = None
+
     ex = Example(a="1", b=2)
     row = ex.to_dict()
-    assert "b" not in row
\ No newline at end of file
+    assert "b" not in row
